@@ -7,6 +7,7 @@ import re
 import json
 from collections import defaultdict, Counter
 from datetime import datetime
+import numpy
 
 from fmqlutils.reporter.reportUtils import MarkdownTable, reportPercent, reportAbsAndPercent
 from fmqlutils.typer.reduceTypeUtils import splitTypeDatas, checkDataPresent, singleValue
@@ -185,7 +186,7 @@ def webReportFormatReference(stationNo, allTypeData, subTypeDatas):
     # type ie/ DICOM IMAGE etc
     summs = []
     summPies = []
-    for typeId in sorted(filerefSubTypesByOT, key=lambda x: sum(y["_total"] for y in filerefSubTypesByOT[x]), reverse=True):
+    for typeId in sorted(filerefSubTypesByOT.keys(), key=lambda x: sum(y["_total"] for y in filerefSubTypesByOT[x]), reverse=True):
         
         subTypeInfos = filerefSubTypesByOT[typeId]
         
@@ -259,17 +260,17 @@ def webReportFormatReference(stationNo, allTypeData, subTypeDatas):
         summPie["Count"] = typeTotal
  
         if len(suffixesCount) == 1:
-            suffixesMU = list(suffixesCount)[0]
+            suffixesMU = suffixesCount.keys()[0]
         else:
             suffixesMU = "<br><br>".join(["{} ({:,})".format(suffix, suffixesCount[suffix]) for suffix in sorted(suffixesCount, key=lambda x: suffixesCount[x], reverse=True)])
 
         if len(caCount) == 1:
-            captureMU = list(caCount)[0].split(":")[1]
+            captureMU = caCount.keys()[0].split(":")[1]
         else:
             captureMU = "<br><br>".join(["{} ({:,})".format(vc.split(":")[1], caCount[vc]) for vc in sorted(caCount, key=lambda x: caCount[x], reverse=True)])
 
         if len(oiCount) == 1:
-            originMU = list(oiCount)[0].split(":")[1]
+            originMU = oiCount.keys()[0].split(":")[1]
         else:
             originMU = "<br><br>".join(["{} ({:,})".format(vc.split(":")[1], oiCount[vc]) for vc in sorted(oiCount, key=lambda x: oiCount[x], reverse=True)])  
 
@@ -324,7 +325,7 @@ An image can be entered in one of three ways - _Capture Workstation_ for manua
         imageTotal=imageTotal, 
         overallFirstCreateDate=overallFirstCreateDate, 
         overallLastCreateDate=overallLastCreateDate, 
-        filerefSubTypesByOTCount=len(filerefSubTypesByOT), 
+        filerefSubTypesByOTCount=len(filerefSubTypesByOT.keys()), 
         objectTypesInfoTotal=objectTypesInfo["_total"], 
         allTypeDataPatientRangeCount=allTypeData["patient"]["rangeCount"],
         totalXRG=totalXRG
@@ -405,7 +406,7 @@ An image can be entered in one of three ways - _Capture Workstation_ for manua
     for ti in sorted(list(majNoSetTIs), key=lambda x: tiGroupingByPDF[x]["NOSET"], reverse=True):
     
         setPDFMU = ", ".join(["{} ({})".format(pdfLabel, tiGroupingByPDF[ti][pdfLabel]) for pdfLabel in tiGroupingByPDF[ti] if pdfLabel != "NOSET"])
-        otUSMU = ", ".join(["{} ({})".format(re.sub(r'\_', ' ', ot), tiUnsetGroupingByOT[ti][ot]) for ot in sorted(tiUnsetGroupingByOT[ti], key=lambda x: tiUnsetGroupingByOT[ti][x], reverse=True)]) if len(tiUnsetGroupingByOT[ti]) > 1 else list(tiUnsetGroupingByOT[ti])[0]
+        otUSMU = ", ".join(["{} ({})".format(re.sub(r'\_', ' ', ot), tiUnsetGroupingByOT[ti][ot]) for ot in sorted(tiUnsetGroupingByOT[ti], key=lambda x: tiUnsetGroupingByOT[ti][x], reverse=True)]) if len(tiUnsetGroupingByOT[ti]) > 1 else tiUnsetGroupingByOT[ti].keys()[0]
         
         tbl.addRow([
             "__{}__".format(ti.split(" [")[0]), 
@@ -422,7 +423,7 @@ An image can be entered in one of three ways - _Capture Workstation_ for manua
     for ti in sorted(list(otherNoSetTIs), key=lambda x: tiGroupingByPDF[x]["NOSET"], reverse=True):
     
         setPDFMU = ", ".join(["{} ({})".format(pdfLabel, tiGroupingByPDF[ti][pdfLabel]) for pdfLabel in tiGroupingByPDF[ti] if pdfLabel != "NOSET"])
-        otUSMU = ", ".join(["{} ({})".format(re.sub(r'\_', ' ', ot), tiUnsetGroupingByOT[ti][ot]) for ot in sorted(tiUnsetGroupingByOT[ti], key=lambda x: tiUnsetGroupingByOT[ti][x], reverse=True)]) if len(tiUnsetGroupingByOT[ti]) > 1 else list(tiUnsetGroupingByOT[ti])[0]
+        otUSMU = ", ".join(["{} ({})".format(re.sub(r'\_', ' ', ot), tiUnsetGroupingByOT[ti][ot]) for ot in sorted(tiUnsetGroupingByOT[ti], key=lambda x: tiUnsetGroupingByOT[ti][x], reverse=True)]) if len(tiUnsetGroupingByOT[ti]) > 1 else tiUnsetGroupingByOT[ti].keys()[0]
         cntAllOfTI = sum(tiGroupingByPDF[ti][pdfLabel] for pdfLabel in tiGroupingByPDF[ti])
         
         tbl.addRow([
@@ -548,8 +549,8 @@ FROM WIKI etc.
 """
 def webReportYR3DICOM(stationNo):
 
-    print("FIRST CHECK: overlap bold alg wrong - had to manually fix in PDF spaces and things run in as does TITLE[sop class oid]")
-    print(x)
+    print "FIRST CHECK: overlap bold alg wrong - had to manually fix in PDF + "\n" spaces and things run in as does TITLE[sop class oid]
+    print x
 
     allThere, details = checkDataPresent(stationNo, [
     
@@ -605,7 +606,7 @@ def webReportYR3DICOM(stationNo):
 
         # REM: split by it so all and 1!
         if "dicom_sop_class" in subTypeInfo:
-            sopClassRef = list(subTypeInfo["dicom_sop_class"]["byValueCount"])[0] # only one
+            sopClassRef = subTypeInfo["dicom_sop_class"]["byValueCount"].keys()[0] # only one
             sopClassUID = sopClassRef.split(" [")[0]
         else:
             sopClassUID = "NOTSET"
@@ -616,7 +617,7 @@ def webReportYR3DICOM(stationNo):
         else:
             if subTypeInfo["spec_subspec_index"]["count"] != subTypeInfo["_total"]:
                 raise Exception("If spec_subspec_index for SOP then except for all of SOP")
-            specSubSpecIndexLabel = list(subTypeInfo["spec_subspec_index"]["byValueCount"])[0].split(" [")[0]
+            specSubSpecIndexLabel = subTypeInfo["spec_subspec_index"]["byValueCount"].keys()[0].split(" [")[0]
                             
         """
         RADIOLOGY and NUCLEAR MEDICINE 
@@ -637,14 +638,14 @@ def webReportYR3DICOM(stationNo):
                 "parent_data_file" in subTypeInfo and
                 subTypeInfo["parent_data_file"]["count"] == subTypeInfo["_total"] and
                 len(subTypeInfo["parent_data_file"]["byValueCount"]) == 1 and
-                re.match(r'RADIOLOGY', list(subTypeInfo["parent_data_file"]["byValueCount"])[0]) and
+                re.match(r'RADIOLOGY', subTypeInfo["parent_data_file"]["byValueCount"].keys()[0]) and
                 
                 "radiology_report" in subTypeInfo and
                 subTypeInfo["radiology_report"]["count"] == subTypeInfo["_total"] and
                 
                 "capture_application" in subTypeInfo and             
                 len(subTypeInfo["capture_application"]["byValueCount"]) == 1 and 
-                list(subTypeInfo["capture_application"]["byValueCount"])[0] == "D:DICOM Gateway" and
+                subTypeInfo["capture_application"]["byValueCount"].keys()[0] == "D:DICOM Gateway" and
                 
                 "pacs_procedure" in subTypeInfo and
                 subTypeInfo["pacs_procedure"]["count"] == subTypeInfo["_total"] and
@@ -653,7 +654,7 @@ def webReportYR3DICOM(stationNo):
                 subTypeInfo["group_parent"]["count"] == subTypeInfo["_total"] and
                 
                 "status" in subTypeInfo and
-                set(subTypeInfo["status"]["byValueCount"]) == set(["1:Viewable"])
+                set(subTypeInfo["status"]["byValueCount"].keys()) == set(["1:Viewable"])
                 
                 # for RAD/NUC, is type_index always IMAGE?
                 # is class_index always CLIN?
@@ -705,7 +706,7 @@ def webReportYR3DICOM(stationNo):
             
                 if not (
                     "status" in subTypeInfo and
-                    set(subTypeInfo["status"]["byValueCount"]) == set(["1:Viewable"])
+                    set(subTypeInfo["status"]["byValueCount"].keys()) == set(["1:Viewable"])
                 ):
                     raise Exception("Expected 2: non RAD/NUC but DICOM Gateway to always have status Viewable ie G/W import is fixed to Viewable")
             
@@ -813,7 +814,7 @@ def webReportYR3DICOM(stationNo):
         if len(counter) > 1:
             cmu = ", ".join(["{} [{:,}]".format(k.split(":")[1] if re.search(r':', k) else k, counter[k]) for k in sorted(counter, key=lambda x: counter[x], reverse=True)])
         else:
-            k = list(counter)[0]
+            k = counter.keys()[0]
             cmu = k if not re.search(r':', k) else k.split(":")[1]      
         return cmu
         
@@ -867,7 +868,7 @@ def webReportYR3DICOM(stationNo):
     
     Either SOP 1.2.840.10008.5.1.4.1.1.77.1.4 or NO SOP 
     """
-    if set(countBySpecIndexBySOPClassNRNCA) == set(["1.2.840.10008.5.1.4.1.1.77.1.4"]):
+    if set(countBySpecIndexBySOPClassNRNCA.keys()) == set(["1.2.840.10008.5.1.4.1.1.77.1.4"]):
         sopClassMsg = "They all share the same SOP Class, _VL Photographic Image Storage [1.2.840.10008.5.1.4.1.1.77.1.4]_"
     else:
         sopClassMsg = "Where SOP Class is set, it is always, _VL Photographic Image Storage [1.2.840.10008.5.1.4.1.1.77.1.4]_"
@@ -924,16 +925,17 @@ def webReportYR3Other(stationNo):
                
 def main():
 
-    assert sys.version_info >= (3, 4)
-
-    try:
-        stationNo = sys.argv[1]
-    except IndexError:
-        raise SystemExit("Usage _EXE_ STATIONNO")
+    assert(sys.version_info >= (2,7))
 
+    if len(sys.argv) < 2:
+        print "need to specify station # ex/ 442 - exiting"
+        return
+        
+    stationNo = sys.argv[1]
+    
     userSiteDir = SITE_DIR_TEMPL.format(stationNo)
     if not os.path.isdir(userSiteDir):
-        raise SystemExit("Expect User Site to already exist with its basic contents")
+        raise Exception("Expect User Site to already exist with its basic contents")
 
     webReportImaging(stationNo)
                  
