@@ -480,9 +480,9 @@ class UserClassifier:
         # ... all seem to have LOA 1
         if len(UserClassifier.PUREZEROSOCREATEDUSER_200_MAND_PROPS - set(userInfo["hasProps"])):
             self.__result["remoteExcludeReasonCount"]["MAND_PROPS"] += 1
-            missingMands = (UserClassifier.PUREZEROSOCREATEDUSER_200_MAND_PROPS - set(userInfo["hasProps"])) - set(["secondary_menu_options", "timestamp"])
+            missingMands = (UserClassifier.PUREZEROSOCREATEDUSER_200_MAND_PROPS - set(userInfo["hasProps"])) - set(["secondary_menu_options", "timestamp", "alias"])
             if len(missingMands) != 0:
-                raise Exception("At this point in Remote Check, only expected mandatory SMO and TimeStamp could be missing but {}".format(
+                raise Exception("At this point in Remote Check, only expected mandatory SMO/ TimeStamp/ Alias could be missing but {}".format(
                                     "/".join(list(missingMands))
                                 ))
             return False
