@@ -12,7 +12,8 @@ import numpy
 from fmqlutils.reporter.reportUtils import MarkdownTable, reportPercent, reportAbsAndPercent
 
 from fmqlutils.typer.reduceTypeUtils import splitTypeDatas, checkDataPresent, singleValue, combineSubTypes, muBVC, muBVCOfSTProp
-from ..webReportUtils import TOP_MD_TEMPL, SITE_DIR_TEMPL, keyStats, flattenFrequencyDistribution, roundFloat, reduce200
+from fmqlutils.cacher.cacherUtils import metaOfVistA
+from ..webReportUtils import ensureWebReportLocations, TOP_MD_TEMPL, SITE_DIR_TEMPL, keyStats, flattenFrequencyDistribution, roundFloat, reduce200
 from userClassifier import UserClassifier
 
 """
@@ -31,7 +32,7 @@ from non subordinate divisions etc.
 
 Note: smallSOSet setup for case where only have small sample of SOs (ie/ take all)  
 """
-def webReportUser(stationNo, deidentify=False, smallSOSet=False):
+def webReportUser(stationNo, deidentify=False):
 
     print("Preparing to make user report for {}{} - loading data ...".format(stationNo, " [DEIDENTIFY]" if deidentify else ""))
 
@@ -43,6 +44,11 @@ def webReportUser(stationNo, deidentify=False, smallSOSet=False):
     ])
     if not allThere:
         raise Exception("Some required data is missing - {}".format(details))
+        
+    ensureWebReportLocations(stationNo)
+        
+    meta = metaOfVistA(stationNo)
+    vistaName = "VistA" if "name" not in meta else meta["name"]
 
     mu = TOP_MD_TEMPL.format("{} Users".format(stationNo), "Users")
 
@@ -61,7 +67,7 @@ def webReportUser(stationNo, deidentify=False, smallSOSet=False):
     overallFirstSODate = createDatePropInfo["firstCreateDate"].split("T")[0]
     overallLastSODate = createDatePropInfo["lastCreateDate"].split("T")[0]
         
-    BLURB_TEMPL = """Of the <span class='yellowIt'>{:,}</span> users known to the system, a minority <span class='yellowIt'>{}</span> ("__Active Users__") signed in between {} and {}, {}.
+    BLURB_TEMPL = """Of the <span class='yellowIt'>{:,}</span> users known to {}, a minority <span class='yellowIt'>{}</span> ("__Active Users__") signed in between {} and {}, the most recent year for which data is available.
 
 Most Active Users are real people but there are "__Machine Users__" for specialized VA batch applications or applications which manage end users themselves.
 
@@ -69,10 +75,10 @@ Most Active Users are real people but there are "__Machine Users__" for speciali
 
     mu += BLURB_TEMPL.format(
         len(userInfoByUserRef),
+        "__{} [{}]__".format(vistaName, stationNo),
         reportAbsAndPercent(len(classification["activeUserRefs"]), len(userInfoByUserRef)),
         overallFirstSODate, 
-        overallLastSODate,
-        "the period for which sign on logs are available" if smallSOSet else "the most recent year for which data is available"
+        overallLastSODate
     )  
     
     if deidentify:
@@ -633,7 +639,7 @@ There are <span class='yellowIt'>{}</span> active Local Users with <span class='
     tbl = MarkdownTable([":LOA", "Count %"])
     for loa in sorted(comboST["level_of_assurance"]["byValueCount"], key=lambda x: comboST["level_of_assurance"]["byValueCount"][x], reverse=True):
         tbl.addRow([
-            "__{}__".format(device), 
+            "__{}__".format(loa), 
             reportAbsAndPercent(comboST["level_of_assurance"]["byValueCount"][loa], comboST["_total"])
         ])
     mu += tbl.md() + "\n\n"
@@ -807,13 +813,8 @@ def main():
         deidentify = sys.argv[2]
     else:
         deidentify = False
-        
-    if len(sys.argv) == 4:
-        smallSOSet = True
-    else:
-        smallSOSet = False
     
-    webReportUser(stationNo, deidentify, smallSOSet)
+    webReportUser(stationNo, deidentify)
     
 if __name__ == "__main__":
     main()
