@@ -26,6 +26,11 @@ title: {}
 
 """
 
+def ensureWebReportLocations(stationNo):
+    reportSiteLocation = SITE_DIR_TEMPL.format(stationNo)
+    if not os.path.isdir(reportSiteLocation):
+        os.mkdir(reportSiteLocation)
+
 def dtdd(dt, dd):
     return "{}\n:    {}\n\n".format(dt, dd)
     
@@ -427,7 +432,7 @@ def reduce2(stationNo, forceNew=False):
     
     return infosByIEN
     
-# ############################ Reduce Location (44) ###########################
+# ################# Reduce Location (44) n Institution (4) ####################
 
 """
 Like other "anchor file" reductions, preludes to more formal reframes (RF) that
@@ -439,26 +444,104 @@ lookup
 Note: allows RF take - right now that RF is just the result of extracting the
 44.001 and other multiples.
 """
-def reduce44(stationNo, useRF=False, forceNew=False): 
+def reduce44(stationNo, useRF=True): # do from RF
 
-    """
-                for litProp in ["patient_friendly_name", "physical_location", "length_of_appointment", "default_appointment_type"]: # includes enum
-                if litProp not in resource:
-                    continue
-                red[litProp] = resource[litProp]
-            for dtProp in ["inactivate_date", "reactivate_date"]:
-                if dtProp not in resource:
-                    continue
-                red[dtProp] = resource[dtProp]["value"]
-            for refProp in ["stop_code_number", "institution", "division", "type_extension", "default_provider"]:
-                if refProp not in resource:
-                    continue
-                    
-    Add mult of provider (list) etc and the letter props
-    """
-    pass
+    jsnFl = TMPWORKING_LOCN_TEMPL.format(stationNo) + "hlReduction.json"
+    try:
+        infosByIEN = json.load(open(jsnFl))
+    except:
+        pass
+    else:
+        return infosByIEN
+    print("First time through, creating hospital location reduction for {}".format(stationNo))
+    sys.stdout.flush()
+    infosByIEN = {}
+    countWProvider = 0
+    countDefaultProviderNotInProvider = 0
+    def copyMProp(resource, red, mprop):
+        if mprop not in resource:
+            return None
+        red[mprop] = set()
+        for mresource in resource[mprop]:
+            pref = "{} [{}]".format(mresource[mprop]["label"], mresource[mprop]["id"].split("-")[1])
+            red[mprop].add(pref)
+        red[mprop] = list(red[mprop])
+        return red
+    institutionsByHPrefix = defaultdict(set) # for mapping
+    cnt = 0
+    for resource in filteredResultIterator(stationNo, "44", useRF=useRF):
+        ien = resource["_id"].split("-")[1]
+        red = {"ien": ien, "label": resource["name"]}
+        infosByIEN[ien] = red
+        cnt += 1
+        if (cnt % 200) == 0:
+            print("processed another 200 to {:,}".format(cnt))
+        for litProp in ["abbreviation", "patient_friendly_name", "physical_location", "length_of_appointment", "default_appointment_type", "noncount_clinic_y_or_n", "clinic_meets_at_this_facility"]: # includes enum
+            if litProp not in resource:
+                continue
+            red[litProp] = resource[litProp]
+        for dtProp in ["inactivate_date", "reactivate_date", "availability_flag"]:
+            if dtProp not in resource:
+                continue
+            red[dtProp] = resource[dtProp]["value"]
+        for refProp in ["stop_code_number", "credit_stop_code", "institution", "division", "type_extension", "default_provider"]:
+            if refProp not in resource:
+                continue
+            refv = resource[refProp]
+            ref = "{} [{}]".format(refv["label"], refv["id"].split("-")[1])
+            red[refProp] = ref
+            if refProp == "institution":
+                hprefix = re.split(r'[ \-\/]', resource["name"])[0]
+                institutionsByHPrefix[hprefix].add(ref)
+        # Mult Availability - note many exs where no appts
+        if "availability" in resource: # want to see if always there if appointments too
+            red["has_availability"] = True
+        if copyMProp(resource, red, "provider"):
+            if "default_provider" in red and red["default_provider"] not in red["provider"]:
+                countDefaultProviderNotInProvider += 1
+            countWProvider += 1
+        copyMProp(resource, red, "privileged_user") # the clerks etc
+        # Note: appointment FLIPPED/REDUCED so won't know that?
+        
+    # Fill in missing instit links based on prefix mappings from those with an instit
+    noMissing = 0
+    noFilled = 0
+    for ien in infosByIEN:
+        info = infosByIEN[ien]
+        if "institution" in info:
+            continue
+        noMissing += 1
+        hprefix = re.split(r'[ \-\/]', info["label"])[0]
+        if hprefix in institutionsByHPrefix and len(institutionsByHPrefix[hprefix]) == 1:
+            info["institution"] = list(institutionsByHPrefix[hprefix])[0]
+            noFilled += 1
+    print("Of {:,} locations missing an institution link, {:,} were filled by heuristic".format(noMissing, noFilled))
+        
+    print("Dumping {:,} locations, {:,} have providers with {:,} having default provider not in provider list".format(len(infosByIEN), countWProvider, countDefaultProviderNotInProvider))
+    json.dump(infosByIEN, open(jsnFl, "w"), indent=4)
+    return infosByIEN
 
-    # TODO: out of custom reports
+def reduce4(stationNo):
+    jsnFl = TMPWORKING_LOCN_TEMPL.format(stationNo) + "4Reduction.json"
+    try:
+        infosByIEN = json.load(open(jsnFl))
+    except:
+        pass
+    else:
+        return infosByIEN
+    infosByIEN = {}
+    for resource in filteredResultIterator(stationNo, "4"):
+        ien = resource["_id"].split("-")[1]
+        red = {"ien": ien, "label": resource["name"]}
+        infosByIEN[ien] = red
+        if "reporting_station" in resource:
+            red["reporting_station"] = "{} [{}]".format(resource["reporting_station"]["label"], resource["reporting_station"]["id"].split("-")[1]) 
+        for prop in ["va_type_code", "status", "npi", "official_va_name", "station_number"]:
+            if prop not in resource:
+                continue
+            red[prop] = resource[prop]
+    json.dump(infosByIEN, open(jsnFl, "w"), indent=4)
+    return infosByIEN
     
 # ############################ Simple Reusable MD Makers ###############################
 
